@@ -1,6 +1,6 @@
 package Config::MVP::Assembler::WithBundles;
-BEGIN {
-  $Config::MVP::Assembler::WithBundles::VERSION = '2.200001';
+{
+  $Config::MVP::Assembler::WithBundles::VERSION = '2.200004';
 }
 use Moose::Role;
 # ABSTRACT: a role to make assemblers expand bundles
@@ -88,6 +88,7 @@ no Moose;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -96,7 +97,7 @@ Config::MVP::Assembler::WithBundles - a role to make assemblers expand bundles
 
 =head1 VERSION
 
-version 2.200001
+version 2.200004
 
 =head1 DESCRIPTION
 
@@ -106,13 +107,15 @@ be treated as bundles.  When any section is ended, if that section represented
 a bundle, its bundle contents will be unrolled and will replace it in the
 sequence.
 
-A package is considered a bundle if the this returns a defined method:
+A package is considered a bundle if C<package_bundle_method> returns a
+defined value (which is the name of a method that will be called on
+that package to retrieve its bundle config).
 
   my $method = $assembler->package_bundle_method($package);
 
-The default implementation looks for a method callde C<mvp_bundle_config>, but
-C<package_bundle_method> can be replaced to allow for other bundle-identifying
-information.
+The default implementation looks for a method called C<mvp_bundle_config>, but
+C<package_bundle_method> can be replaced with one that returns the name of a
+different bundle-identifying method-name.
 
 Bundles are expanded by a call to the assembler's
 C<replace_bundle_with_contents> method, like this:
@@ -148,10 +151,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
