@@ -1,10 +1,10 @@
 package Config::MVP::Section;
-BEGIN {
-  $Config::MVP::Section::VERSION = '2.200001';
+{
+  $Config::MVP::Section::VERSION = '2.200004';
 }
 use Moose 0.91;
 
-use Class::Load 0.06 ();
+use Class::Load 0.17 ();
 use Config::MVP::Error;
 
 # ABSTRACT: one section of an MVP configuration sequence
@@ -140,7 +140,7 @@ sub load_package {
   my ($self, $package, $plugin) = @_;
 
   Class::Load::load_optional_class($package)
-    or $self->missing_package($plugin, $package);
+    or $self->missing_package($package, $plugin);
 }
 
 
@@ -189,6 +189,7 @@ no Moose;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -197,7 +198,7 @@ Config::MVP::Section - one section of an MVP configuration sequence
 
 =head1 VERSION
 
-version 2.200001
+version 2.200004
 
 =head1 DESCRIPTION
 
@@ -299,10 +300,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
